##  Overview
You can import fact sheets into SAP LeanIX using the inboundFactSheet processor of the Integration API. By the end of this tutorial, you'll be able to:
  * Import application fact sheets into SAP LeanIX, including basic information like names and descriptions.
  * Update imported fact sheets with business criticality values.
  * Set up value mappings for fact sheet fields in the processor configuration.
